pub fn describe_and_assert<F: FnOnce(&mut TestContext)>(description: &str, f: F)Expand description
Run a describe block and assert all tests pass.
pub fn describe_and_assert<F: FnOnce(&mut TestContext)>(description: &str, f: F)Run a describe block and assert all tests pass.