InputType

Enum InputType 

pub enum InputType {
Show 14 variants Text, Email, Password, Tel, Url, Number, Date, Time, Search, Radio, Checkbox, Select, Textarea, Hidden,
}
Input type for form fields.

Variants



Text



Email



Password



Tel



Url



Number



Date



Time



Search



Radio



Checkbox



Select



Textarea



Hidden

Implementations

Source

impl InputType

pub const fn should_have_autocomplete(&self) -> bool

Check if this input type should have autocomplete for WCAG 1.3.5.