Struct FixtureContext
Source pub struct FixtureContext {
pub fixture: Fixture,
pub test_name: String,
pub output_dir: Option<String>,
}
Context for fixture-based tests.
Output directory for generated files
Create a new fixture context.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.